Learn R Programming

BcDiag (version 1.0.2)

anomedOnlybic: The anomedOnlybic function

Description

Provides ANOVA and median polish residual plots for biclusterd data.

Usage

anomedOnlybic (dset,bres,fit="boxplot",mname="biclust",bnum=1)

Arguments

dset
Data matrix.
bres
Bicluster result.
fit
A string value to fit a plot; 'aplot','mplot','anovbplot','mpolishbplot','boxplot'
mname
Method name; 'biclust', 'isa2' or 'fabia'
bnum
Existed biclusters; '1','2'...

Value

  • residual plots or residual box plots.

Details

A function provides residuals plots for biclustered data based on anova and median polish. The function checked the required parameter values and fit the plot according to the user Requirement and generate an error message and suggestion if it is not fulfilled.

References

Van't Veer, L.J., Dai, H., van de Vijver, M.J., He, Y.D., Hart, A.A. et al. (2002). Gene expression profiling predicts clinical outcome of breast cancer,Nature, 415, 530-536. Kaiser S. and Leisch F. (2008). A Toolbox for Bicluster Analysis in R. Ludwigstrasse. 33.

See Also

plotOnlybic

Examples

Run this code
data(breastc)
# find bicluster using one of biclust algorithms
bic<- biclust(breastc, method=BCPlaid())
#fit residual boxplot from ANOVA
anomedOnlybic(dset=breastc,bres=bic,fit="boxplot",mname="biclust")

Run the code above in your browser using DataLab