Learn R Programming

BcDiag (version 1.0.2)

indexedBic: The indexedBic function.

Description

Supportive function for profileBic, exploreBic, exploreOnlybic and anomedOnlybic used to extract biclusterd index from a dataset based on 'biclust','fabia' and 'isa2' algorithms.

Usage

indexedBic(dset, bres, mname = c("fabia", "isa2", "biclust"), bnum)

Arguments

dset
Data matrix
bres
Bicluster result
mname
Method name; 'biclust', 'isa2' or 'fabia'
bnum
Existed biclusters; '1','2'...

Value

  • Indicies of biclustered data.

Details

Its main purpose is for internal usage and extracts the index of biclusterd rows and columns from the dataset and returns to the main function. by knowing the indexed of the biclusterd data, we can easily identified and grouped the biculsterd data from the clusterd ones.

See Also

profileBic, exploreBic, exploreOnlybic, anomedOnlybic