Learn R Programming

BcDiag (version 1.0.2)

profileBic: The profileBic function.

Description

Provides profile plots for biclusterd and clusterd data parallely.

Usage

profileBic(dset, bres, mname = c("fabia", "isa2", "biclust"), bplot = "all",
gby = "genes", bnum = 1, teta = 120, ph = 30)

Arguments

dset
Data matrix.
bres
Bicluster result.
mname
Method name; 'biclust', 'isa2' or 'fabia'
bplot
types of plots;'all','lines','boxplot','histogram' or '3D'
gby
grouped by; 'genes', or 'conditions'
bnum
Existed biclusters; '1','2'...
teta
numerical value to rotate the 3D; 0,90,180,..
ph
numerical value to rotate the 3D; 0,90,180

Value

  • profile.bic (dset, bres, mname="biclust", bplot="all", gby="genes", bnum=1, teta=120, ph=30)

Details

The profile.bic function checks all parameters are correctly submitted then it calls a function indexedBic to identify the biclusterd and clusterd data.

References

Van't Veer, L.J., Dai, H., van de Vijver, M.J., He, Y.D., Hart, A.A. et al. (2002). Gene expression profiling predicts clinical outcome of breast cancer,Nature, 415, 530-536. Kaiser S. and Leisch F. (2008). A Toolbox for Bicluster Analysis in R. Ludwigstrasse. 33.

See Also

profileAll

Examples

Run this code
#manupilate the biclust result
data(breastc)
bic<- biclust(breastc, method=BCPlaid())# 3 bicluster found.
#3D profile plot for biclusterd and clusterd data.
profileBic(dset=breastc,bres=bic,mname="biclust",
bplot="3D",gby="genes",teta=-30,ph=50,bnum=1)

Run the code above in your browser using DataLab